[![Downloads](https://static.pepy.tech/badge/automation-editor)](https://pepy.tech/project/automation-editor)

[![Codacy Badge](https://app.codacy.com/project/badge/Grade/b7d32ed8600b4bd2a2f3e960f46f2ad0)](https://www.codacy.com/gh/JE-Chen/Integration-testing-environment/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=JE-Chen/Integration-testing-environment&amp;utm_campaign=Badge_Grade)

[![AutomationEditor Stable Python3.9](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_9.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_9.yml)

[![AutomationEditor Stable Python3.10](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_10.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_10.yml)

[![AutomationEditor Stable Python3.11](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_11.yml/badge.svg)](https://github.com/Intergration-Automation-Testing/AutomationEditor/actions/workflows/stable_python3_11.yml)

[![Documentation Status](https://readthedocs.org/projects/automationeditor/badge/?version=latest)](https://automationeditor.readthedocs.io/en/latest/?badge=latest)

[AutomationIDE Doc Click Here!](https://automationeditor.readthedocs.io/en/latest/)

[Using this IDE edit tkinter video](https://www.youtube.com/watch?v=VXm8L2qrdSU&ab_channel=JEChen)

---

## Notice
> * If you can't run program and get argument or internal error on windows, Please update your powershell.
> * https://github.com/PowerShell/PowerShell/releases

---
## What is Automation Editor
> Project Kanban \
> https://github.com/orgs/Integration-Automation/projects/2/views/1 \
> * Native support AutoControl script.
> * Native support APITestka script.
> * Native support Load Density script.
> * Native support WEB Runner script.
> * Native support Mail Thunder script.
> * Native support File Automation script.
> * Native support Front Engine script.
> * Automation instance monitor.
> * Automation project support.
> * Docs support.
> * BingGPT (requires setting up cookies, tutorial available in the IDE) 
> * DALL-E3 Bing version for image generation (requires setting up another type of cookie, tutorial available in the IDE)
> * Auto-save (available after the first save or after opening a file), auto-complete, jump to definition. 
> * Bilingual interface (English, Traditional Chinese) Choose font and size. 
> * Tabbed browsing, split window functionality. 
> * Embedded browser. 
> * Embedded Jupyter and IPython. 
> * Built-in automation packages.
> * Multiple UI style choices. 
> * Python venv and management to choose the Python interpreter to use.
> * Code style checking and auto-formatting (PEP8). 
> * Debugger.
> * Multiple Shell command executors (run multiple Shells at once). 
> * Multiple program executors (run multiple programs at once). Custom colors.


---

### install
> pip install automation_editor

![Architecture Diagram](architecture_diagram/AutomationEditorArchitectureDiagram.drawio.png)
